==> programy-3.0.2.tar.gz: programy-3.0.2/programy/storage/entities/linked.py <==
"""
Copyright (c) 2016-2018 Keith Sterling http://www.keithsterling.com

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated
documentation files (the "Software"), to deal in the Software without restriction, including without limitation
the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software,
and to permit persons to whom the Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the
Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO
THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
"""

class LinkedAccountStore(object):

    def link_accounts(self, primary_userid, linked_userid):
        raise NotImplementedError("link_accounts missing from Linked Account DAO")

    def unlink_account(self, primary_userid, linked_userid):
        raise NotImplementedError("unlink_account missing from Linked Account DAO")

    def unlink_accounts(self, primary_userid):
        raise NotImplementedError("unlink_accounts missing from Linked Account DAO")

    def linked_accounts(self, primary_userid):
        raise NotImplementedError("linked_accounts missing from Linked Account DAO")

    def primary_account(self, linked_userid):
        raise NotImplementedError("primary_account missing from Linked Account DAO")

==> programy-3.8.5.tar.gz: programy-3.8.5/programy/storage/entities/linked.py <==
"""
Copyright (c) 2016-2019 Keith Sterling http://www.keithsterling.com

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated
documentation files (the "Software"), to deal in the Software without restriction, including without limitation
the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software,
and to permit persons to whom the Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the
Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO
THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
"""

class LinkedAccountStore(object):

    def link_accounts(self, primary_userid, linked_userid):
        raise NotImplementedError("link_accounts missing from Link Store")

    def unlink_accounts(self, userid):
        raise NotImplementedError("unlink_accounts missing from Link Store")

    def primary_account(self, secondary_userid):
        raise NotImplementedError("primary_account missing from Link Store")
